@@ -5,7 +5,7 @@ use Test::Builder::Module;
 use Test::Name::FromLine;
 use Text::MatchedPosition;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 our @ISA = qw/Test::Builder::Module/;
 
@@ -97,8 +97,6 @@ sub expected {
     $self;
 }
 
-sub expect { shift->expected(@_) }
-
 sub got {
     my ($self, $value) = @_;
 
@@ -361,6 +359,10 @@ sub throw_ok {
     eval { shift->() };
 
     _tb->ok(!!$@, $self->_specific('_name', $_[0]));
+
+    $self->_reset;
+
+    $self;
 }
 
 sub throw {
@@ -395,7 +397,7 @@ sub catch {
     my $ret = _tb->like(
         $self->_specific('_got', undef),
         $regex,
-        $_[0] || 'Thrown correctly',
+        $self->_specific('_name', $_[0]),
     );
 
     $self->_reset;
@@ -403,6 +405,71 @@ sub catch {
     $ret;
 }
 
+sub warnings_ok {
+    my ($self, $code, $name) = @_;
+
+    my $warn = 0;
+    eval {
+        local $SIG{__WARN__} = sub { $warn++ };
+        $code->();
+    };
+    if (my $e = $@) {
+        _tb->ok(FAIL);
+        $self->diag("An exception happened: $e");
+    }
+
+    _tb->ok($warn > 0, $self->_specific('_name', $name));
+
+    $self->_reset;
+
+    $self;
+}
+
+sub warnings {
+    my ($self, $code, $regex, $name) = @_;
+
+    die 'The `warn` method expects code ref.' unless ref $code eq 'CODE';
+
+    my @warns;
+    eval {
+        local $SIG{__WARN__} = sub { push @warns, shift };
+        $code->();
+    };
+    if (my $e = $@) {
+        _tb->ok(FAIL);
+        $self->diag("An exception happened: $e");
+    }
+
+    if (scalar @warns > 0) {
+        my $warn = join "\t", @warns;
+        if (defined $regex) {
+            _tb->like($warn, $regex, $self->_specific('_name', $name));
+            $self->_reset;
+        }
+        else {
+            $self->got($warn);
+        }
+    }
+    else {
+        _tb->ok(FAIL);
+        $self->diag(q|Failed, because there is no warnings.|);
+    }
+
+    $self;
+}
+
+{
+    no warnings 'once';
+    *expect = *expected;
+
+    *warn_ok    = *warnings_ok;
+    *warning_ok = *warnings_ok;
+
+    *warning = *warnings;
+
+    *done = *done_testing;
+}
+
 1;
 
 __END__
@@ -446,6 +513,7 @@ Test::Arrow - Object-Oriented testing library
     #           matched at line: 1, offset: 2
 
     $arr->throw(sub { die 'Baz' })->catch(qr/^Ba/);
+    $arr->warnings(sub { warn 'Bar' })->catch(qr/^Ba/);
 
 
 =head1 DESCRIPTION
@@ -610,6 +678,22 @@ Actually, you can execute a test even only C<throw> method
 
     $arr->throw(sub { die 'Baz' }, qr/^Ba/);
 
+=head3 warnings_ok($code_ref)
+
+It makes sure that $code_ref gets warnings.
+
+    $arr->warnings_ok(sub { warn 'heads up' });
+
+There are aliases of C<warnings_ok> method: C<warning_ok>, C<warn_ok>.
+
+=head3 warnings($code_ref)
+
+C<warnings> method is called like below:
+
+    $arr->warnings(sub { warn 'heads up' })->catch(qr/^heads/);
+
+C<warning> is an alias of C<warnings>.
+
 =head2 BAIL OUT
 
 =head3 BAIL_OUT($why)
@@ -663,6 +747,9 @@ Declare of done testing.
 
 B<Note> that you must never put C<done_testing> inside an C<END { ... }> block.
 
+=head3 done
+
+Alias of done_testing
 
 =head2 CONSTANTS
 
@@ -679,7 +766,7 @@ B<Note> that you must never put C<done_testing> inside an C<END { ... }> block.
 
 =begin html
 
-<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.09-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582638671"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582638671&branch=master"/></a>
+<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.10-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582780893"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582780893&branch=master"/></a>
 
 =end html
 
